
Missing authentication or authorisation
-------

**Description:**

If pages are not properly checked for authentication or authorisation, an attacker could 
abuse these flaws. The consequences are differ per application but may lead to 
high risk vulnerabilities.


**Solution:**

You should verify all access controls are implemented properly in order to
prevent a user access data/functions which he was not intended to use.





	
